@@ -1,6 +1,7 @@
 # UTF-8 encoded Brazilian Portuguese language file for use with Oddmuse
 #
 # Copyright (c) 2003  Marcelo Toledo <rw@locked.org>.
+# Copyright (c) 2006, 2007  Hélio Nunes <dedalu@dedalu.art.br>.
 #
 # Permission is granted to copy, distribute and/or modify this
 # document under the terms of the GNU Free Documentation License,
@@ -15,56 +16,60 @@
 # Create a modules subdirectory in your data directory, and put the
 # file in there. It will be loaded automatically.
 #
-# This translation was last checked for Oddmuse version 1.195.
+# This translation was last checked for Oddmuse version 1.753.
 #
-$ModulesDescription .= '<p>$Id: brazilian-portuguese-utf8.pl,v 1.4 2006/08/18 22:46:10 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: brazilian-portuguese-utf8.pl,v 1.12 2007/08/19 11:42:07 as Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
-Leitura não permitida: usuário, ip, ou rede está bloqueada.
+Leitura não permitida: usuário, ip ou rede bloqueados.
+Login
+Entrar
+Error
+Erro
 %s calls
-
+%s chamadas
 Could not create %s
-Não foi possivel criar %s
+Não foi possível criar %s
 Invalid UserName %s: not saved.
-Usuário inválido %s: nada salvo.
+NomeUsuário inválido %s: nada salvo.
 UserName must be 50 characters or less: not saved
-NomeUsuario deve ter 50 caracteres ou menos: nada salvo
+NomeUsuário deve ter 50 caracteres ou menos: nada salvo
 This page contains an uploaded file:
-Esta página contém um arquivo carregado:
+Essa página contém um arquivo enviado:
 Recursive include of %s!
-
+Inclusão recursiva de %s!
 Clear Cache
-
+Limpar Cache
 Main lock obtained.
-Trava principal obtida.
+Obtido bloqueio principal.
 Main lock released.
-Trava principal liberado.
+Liberado bloqueio principal.
+Journal
+Diário
+More...
+Mais...
 Comments on this page
-Commentários sobre esta página
+Comentários sobre essa página
 XML::RSS is not available on this system.
-XML::RSS não existe neste sistema
+XML::RSS não está disponível nesse sistema
 diff
 diferenças
 history
 histórico
 %s returned no data, or LWP::UserAgent is not available.
-
+%s não retornou dados ou LWP::UserAgent não está disponível.
 RSS parsing failed for %s
-
+Análise RSS falhou para %s
 No items found in %s.
-
+Nenhum ítem encontrado em %s.
+ . . . . 
  . . . . 
-
 Click to edit this page
-Clique para editar esta página
-image
-imagem
-download
-download
+Clique para editar essa página
 CGI Internal error: %s
 Erro interno de CGI : %s
 Invalid action parameter %s
-Parametro de ação inválido %s
+Parâmetro de ação inválido %s
 Invalid URL.
 URL inválida.
 Page name is missing
@@ -76,13 +81,15 @@ Página %s inválida (não pode terminar com .db)
 Invalid Page %s (must not end with .lck)
 Página %s inválida (não pode terminar com .lck)
 Invalid Page %s
-Página %s invália
+Página %s inválida
 Preview:
 Prever:
 Preview only, not yet saved
-Visualização apenas, nada foi salvo
+Previsão apenas, nada foi salvo
 Please go on to %s.
-Por favor vá para %s
+Por favor, vá para %s.
+All changes for %s
+Todas as alterações para %s
 No updates since %s
 Nenhuma atualização desde %s
 Updates since %s
@@ -94,69 +101,81 @@ Atualizações no último %s dia
 for %s only
 para %s apenas
 List latest change per page only
-Mostra só as últimas modificações por página
+Listar apenas últimas alterações por página
 List all changes
-Mostra todas as modificações
+Listar todas as alterações
 Skip rollbacks
-
+Ocultar alterações desfeitas
 Include rollbacks
-
+Incluir alterações desfeitas
 List only major changes
-Mostra só as modificações maiores
+Listar só as alterações maiores
 Include minor changes
-Inclui também as modificações menores
+Incluir também as alterações menores
 %s days
 %s dias
 List later changes
-Mostra novas modificações
+Listar as últimas alterações
+RSS
+RSS
+RSS with pages
+RSS com páginas
+RSS with pages and diff
+RSS com páginas e diferenças
 Filters
 Filtros
 Title:
-Título
+Título:
 Title and Body:
 Título e Corpo:
 Username:
 Usuário:
 Host:
-
+Máquina:
+Follow up to:
+Depois do usuário:
 Language:
-Língua:
+Idioma:
 Go!
 Ir!
 (minor)
-(mínima)
+(menor)
 rollback
 desfazer
 new
 novo
 from %s
 de %s
+: 
+: 
 This page is too big to send over RSS.
-Esta página é grande demais para enviar por RSS.
+Essa página é grande demais para ser enviada por RSS.
 History of %s
 Histórico de %s
 Compare
 Comparar
 Deleted
-
+Excluída
 Mark this page for deletion
-
+Marcar essa página para exclusão
 No other revisions available
-
+Outras versões não disponíveis
 current
-
+atual
 Revision %s
-Revisão %s
+Versão %s
 Contributors to %s
-
+Colaboradores para %s
 Missing target for rollback.
-Faltou alvo para desfazer mudança.
+Faltou alvo para desfazer.
 Target for rollback is too far back.
-Alvo para desfazer mudança é muito antigo.
+Alvo para desfazer é muito antigo.
+A username is required for ordinary users.
+Um nome de usuário é requerido para usuários normais.
 Rolling back changes
-Desfazendo mudanças
+Desfazendo alterações
 The two revisions are the same.
-As duas revisões são idênticas
+As duas versões são idênticas.
 Editing not allowed for %s.
 Edição não permitida para %s.
 Rollback to %s
@@ -164,7 +183,7 @@ Desfazer para %s
 %s rolled back
 %s desfeito
 to %s
-
+para %s
 Index of all pages
 Índice de todas as páginas
 Wiki Version
@@ -176,9 +195,9 @@ Senha
 Run maintenance
 Manutenção
 Unlock site
-Desbloquear sítio
+Desbloquear site
 Lock site
-Bloquear sítio
+Bloquear site
 Install CSS
 Instalar CSS
 Unlock %s
@@ -188,107 +207,109 @@ Bloquear %s
 Administration
 Administração
 Actions:
-Ações
+Ações:
 Important pages:
 Páginas importantes:
 To mark a page for deletion, put <strong>%s</strong> on the first line.
-Para marcar uma página para exclusão, escreva <strong>%s</strong> na primeira linha
+Para marcar uma página para exclusão, coloque <strong>%s</strong> na primeira linha
 [Home]
-[Ínicio]
+[Início]
 redirected from %s
 redirecionado de %s
 Click to search for references to this page
-Clique para buscar referência a esta página
+Clique para buscar referências a essa página
 Cookie: 
 Cookie:
 Warning
 Atenção
 Database is stored in temporary directory %s
-Banco de dados é armazenado no diretório temporario %s
+O banco de dados é armazenado no diretório temporário %s
 %s seconds
 %s segundos
 The same page on other sites:
-A mesma página noutro lado:
+A mesma página em outros sites:
 EditNearLinks
-
+EditarLinksPróximos
 Last edited
-Ultima edição
+Última edição
 Edited
 Editado
 by %s
-de %s
-(diff)
+por %s
 (diff)
+(diferença)
 Edit revision %s of this page
-Editar a revisão %s desta página
+Editar a versão %s dessa página
 Edit this page
-Editar esta página
+Editar essa página
+e
 e
-
 This page is read-only
-Esta página é apenas para leitura
+Essa página é apenas para leitura
 View other revisions
-Ver outras revisões
+Ver outras versões
 View current revision
-Ver a versão corrente
+Ver a versão atual
 View all changes
-Ver todas as mudanças
+Ver todas as alterações
 View contributors
-
+Ver colaboradores
 Homepage URL:
-
+URL da página inicial:
 s
 s
 Save
 Salvar
 p
-
+p
 Preview
 Prever
 Search:
 Buscar:
 f
-
+f
 Replace:
 Substituir:
+Delete
+Excluir
 Validate HTML
 Validar HTML
 Validate CSS
 Validar CSS
 Last edit
-
+Última edição
 Difference between revision %1 and %2
-Diferença (entre a revisão %1 e %2)
+Diferença (entre versão %1 e %2)
 revision %s
-revisão %s
+versão %s
 current revision
-versão corrente
+versão atual
 Last major edit (%s)
-
+Última edição maior (%s)
 later minor edits
-
+últimas edições menores
 No diff available.
-Nenhum diff disponivel.
+Nenhum diff disponível.
 Old revision:
-Revisão antiga:
+Versão antiga:
 Changed:
 Alterado:
 Deleted:
-
+Excluído:
 Added:
 Adicionado:
 to
 para
 Revision %s not available
-Revisão %s não disponivel
+Versão %s não disponível
 showing current revision instead
-ao invéz mostrando versão corrente
+mostrando, em vez, a versão atual
 Showing revision %s
 Mostrando versão %s
 Cannot save a nameless page.
-Não se pode salvar uma página sem nome.
+Impossível salvar uma página sem nome.
 Cannot save a page without revision.
-Não se pode salvar uma página sem revisão.
+Impossível salvar uma página sem versão.
 Cannot open %s
 Não foi possível abrir %s
 Cannot write %s
@@ -296,13 +317,13 @@ Não foi possível escrever %s
 Cannot create %s
 Não foi possível criar %s
 Could not get %s lock
-Não foi possível conseguir a trava %s
+Não foi possível conseguir o bloqueio %s
 The lock was created %s.
 O bloqueio foi criado %s.
 This operation may take several seconds...
-Essa operação pode demorar alguns segundos...
+Essa operação pode demorar vários segundos...
 Forced unlock of %s lock.
-Desbloqueio forcado de %s
+Desbloqueio forçado de %s
 No unlock required.
 Nenhum desbloqueio necessário.
 %s hours ago
@@ -322,73 +343,79 @@ agora
 Edit Denied
 Edição negada
 Editing not allowed: user, ip, or network is blocked.
-Edição não permitida: usuário, ip, ou rede está bloqueada.
+Edição não permitida: usuário, ip ou rede bloqueados.
 Contact the wiki administrator for more information.
 Contate o administrador do wiki para maiores informações.
 The rule %s matched for you.
-A regra %s confere para você.
+A regra %s coincide para você.
 See %s for more information.
 Para mais informações, veja %s.
 Editing not allowed: %s is read-only.
-Edição não permitida: %s is apenas para leitura.
+Edição não permitida: %s é apenas para leitura.
 Only administrators can upload files.
-Somente administradores podem carregar arquivos.
+Somente administradores podem enviar arquivos.
 Editing revision %s of
-Editando revisão %s de
+Editando versão %s de
 Editing %s
 Editando %s
 Editing old revision %s.
-Editando antiga revisão %s.
+Editando versão antiga %s.
 Saving this page will replace the latest revision with this text.
-Salvando esta página irá substituir a ultima revisão com esse texto.
+Salvar essa página irá substituir a última versão com esse texto.
 Summary:
 Sumário:
 This change is a minor edit.
-Esta atualização é miníma.
+Essa atualização é mínima.
+Cancel
+Cancelar
 Replace this file with text
-Escrever texto em vez do arquivo presente
+Substituir esse arquivo por texto
 Replace this text with a file
-Usar um arquivo em vez do texto presente
+Substituir esse texto por arquivo
 File to upload: 
-Arquivo à usar: 
+Arquivo a enviar: 
 Files of type %s are not allowed.
 Arquivos do tipo %s não são permitidos.
 Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
-Sua senha é salva em um cookie, caso esteja ativado no seu navegador. Cookies podem se perder se você conectar de outra maquina, outra conta, ou outro software.
+Sua senha é salva em um cookie, caso esteja ativado no seu navegador. Cookies podem se perder se você se conectar de outra máquina, de outra conta ou usando outro software.
 You are currently an administrator on this site.
-Você é atualmente um administrador neste site.
+Atualmente você é um administrador nesse site.
 You are currently an editor on this site.
-Você é atualmente um editor neste site.
+Atualmente você é um editor nesse site.
 You are a normal user on this site.
-Você é um usuario normal neste site.
+Você é um usuário normal nesse site.
 Your password does not match any of the  administrator or editor passwords.
 Sua senha não confere com nenhuma dos administradores ou editores.
 Password:
 Senha:
 This site does not use admin or editor passwords.
-Este site não usa senhas de administrador ou editor.
+Esse site não usa senhas de administrador ou editor.
 This operation is restricted to site editors only...
 Essa operação é restrita aos editores do site...
 This operation is restricted to administrators only...
 Essa operação é restrita aos administradores...
 SampleUndefinedPage
-ExemploPaginaNaoDefinida
+ExemploPáginaNãoDefinida
 Sample_Undefined_Page
-Exemplo_Pagina_Nao_Definida
+Exemplo_Página_Não_Definida
 Rule "%1" matched "%2" on this page.
-
+Regra "%1" coincidiu com "%2" nessa página.
+Reason: %s.
+Causa: %s.
+Reason unknown.
+Causa desconhecida.
 Without normal pages
-
+Ocultar páginas normais
 Include normal pages
-
+Incluir páginas normais
 Without permanent anchors
-
+Ocultar âncoras permanentes
 Include permanent anchors
-
+Incluir âncoras permanentes
 Without near pages
-
+Ocultar páginas próximas
 Include near pages
-
+Incluir páginas próximas
 (for %s)
 (para %s)
 Filter:
@@ -400,9 +427,9 @@ Substituído: %s
 Search for: %s
 Buscar por: %s
 View changes for these pages
-Ver câmbios para estas págians
+Ver alterações nessas páginas
 Search sites on the %s as well
-Estender a busca para os sítios no %s
+Estender a busca para os sites no %s
 and
 e
 or
@@ -412,35 +439,35 @@ Buscando os resultados de %s:
 Near pages:
 Páginas próximas:
 last updated
-ultima atualização
+última atualização
 by
 por
 Transfer Error: %s
 Erro de transferência: %s
 Browser reports no file info.
-
+Navegador reporta não haver informações sobre o arquivo.
 Browser reports no file type.
-
+Navegador reporta não haver tipo de arquivo.
 The page contains banned text.
-
+Essa página contém texto banido.
 No changes to be saved.
-Nenhuma mudança para ser salva.
+Nenhuma alteração para ser salva.
 This page was changed by somebody else %s.
 Esta página foi editada por outra pessoa %s.
 The changes conflict.  Please check the page again.
-
+As alterações são conflitantes. Por favor, verifique essa página novamente.
 Please check whether you overwrote those changes.
-Se faz favor controle se você  esses câmbios.
+Por favor, verifique se você sobrescreveu aquelas alterações.
 Anonymous
 Anônimo
 Cannot delete the index file %s.
 Não foi possível excluir o arquivo de índice %s.
 Please check the directory permissions.
-Cheque as permissões do diretório.
+Por favor, verifique as permissões do diretório.
 Your changes were not saved.
-Suas mudanças não foram salvas
+Suas alterações não foram salvas
 Could not get a lock to merge!
-Não foi possivel bloquear para combinar!
+Não foi possível bloquear para combinar!
 you
 o que você escreveu
 ancestor
@@ -452,67 +479,67 @@ Executar Manutenção
 Maintenance not done.
 Manutenção não concluída.
 (Maintenance can only be done once every 12 hours.)
-(Manutenção pode ser feita apenas a cada 12 horas.)
+(A manutenção só pode ser feita a cada 12 horas.)
 Remove the "maintain" file or wait.
-Romove o arquivo "manter" ou esperar.
+Remova o arquivo "maintain" ou aguarde.
 Expiring keep files and deleting pages marked for deletion
-Expirando mantém arquivos e deletando páginas marcadas para deletar
+Expirando arquivos "keep" e excluindo páginas marcadas para exclusão
 not deleted: 
 não excluído: 
 deleted
 excluído
 Moving part of the %s log file.
-Movendo parte de %s arquivo de log.
+Movendo parte do arquivo de log %s.
 Could not open %s log file
-Não foi possivel abrir o arquivo %s de log
+Não foi possível abrir o arquivo de log %s
 Error was
-Erro foi
+O erro foi
 Note: This error is normal if no changes have been made.
-Obaservação: Esse erro é normal se nenhuma alteração foi feita.
+Observação: Esse erro é normal se nenhuma alteração foi feita.
 Moving %s log entries.
-Movendo %s entrada de log.
+Movendo %s entradas de log.
 Getting page index file for %s.
-
+Obtendo arquivo de índice de página para %s.
 Set or Remove global edit lock
-Marque ou Remova trava global de edição
+Marcar ou Remover o bloqueio global de edição
 Edit lock created.
-Trava de edição criada.
+Bloqueio de edição criado.
 Edit lock removed.
-Trava de edição removido.
+Bloqueio de edição removido.
 Set or Remove page edit lock
-Marque ou Remova trava de ediçao de páginas
+Marcar ou Remover bloqueio de edição de páginas
 Lock for %s created.
-Trava para %s criado.
+Bloqueio para %s criado.
 Lock for %s removed.
-Trava para %s removido:
+Bloqueio para %s removido:
 Displaying Wiki Version
 Mostrando a versão do Wiki
 Show dependencies
 Mostrar dependências
 Inter links:
-
+Links inter-:
 Near links:
-
+Links próximos:
 Show parsed link data
-
+Exibir análise de links
 Too many connections by %s
 Muitas conexões de %s
 Please do not fetch more than %1 pages in %2 seconds.
-Se faz favor não busque mais do que %1 páginas em %2 segundos.
+Por favor, abra mais do que %1 páginas em %2 segundos.
 Check whether the web server can create the directory %s and whether it can create files in it.
-
+Verifique se o servidor web pode criar o diretório %s e se pode criar arquivos nele.
 anchor first defined here: %s
-
+âncora definida primeiro aqui: %s
 Click to search for references to this permanent anchor
-
+Clique para buscar referências a essa âncora permanente
 the page %s also exists
 a página %s também existe
 Copy one of the following stylesheets to %s:
-
+Copie uma das seguintes folhas de estilo para %s:
 Deleting %s
 Excluindo %s
 Deleted %s
-Excluído
+Excluído %s
 Renaming %1 to %2.
 Renomeando %1 para %2.
 The page %s does not exist
@@ -528,7 +555,7 @@ Renomeado de %s
 Renamed %1 to %2.
 Renomeado %1 para %2
 Immediately delete %s
-Excluir imadiatamente %s
+Excluir imediatamente %s
 Rename %s to:
 Renomear %s para:
 Learn more...
@@ -537,24 +564,32 @@ Complete Content
 Conteúdo completo
 The main page is %s.
 A página principal é %s.
+Archive:
+Arquivar:
+Rebuild BackLink database
+Recriar banco de dados LinkRetorno
+Internal Page: 
+Página interna:
+Pages that link to this page
+Páginas que possuem links para essa página
 Cannot highlight the language %s.
 Não foi possível destacar a linguagem %s.
 Recent Visitors
 Visitantes recentes
 some action
-
+alguma ação
 was here
-
+esteve aqui
 and read
-
+e leu
 Illegal year value: Use 0001-9999
-
+Valor ilegal para ano: Use 0001-9999
 The match parameter is missing.
-
+O parâmetro de coincidência está faltando.
 Page Collection for %s
-
+Coletânea de páginas para %s
 Previous
-Prévio
+Anterior
 Next
 Próximo
 Calendar %s
@@ -597,62 +632,92 @@ November
 Novembro
 December
 Dezembro
+set %s
+marcar %s
+unset %s
+desmarcar %s
 Clustermap
-
+MapaCluster
 Pages without a Cluster
-
+Páginas sem um Cluster
 Comments on 
 Comentários sobre 
 Comment on 
 Comentar sobre 
 Compilation for %s
-
+Compilação para %s
 Compilation tag is missing a regular expression.
-
+Falta expressão regular na etiqueta de compilação.
+List spammed pages
+Listar páginas com spam
 Despamming pages
-
+Limpar spam das páginas
+Spammed pages
+Páginas com spam
 Cannot find revision %s.
-
+Não foi possível localizar a versão %s.
 Revert to revision %1: %2
-Reverter para revisão %1: %2
+Reverter para versão %1: %2
 Marked as %s.
 Marcado como %s.
 Cannot find unspammed revision.
-
+Não foi possível localizar versão sem spam.
+Recover Draft
+Recuperar Rascunho
+No text to save
+Não há texto para salvar
+Draft saved
+Rascunho salvo
+Draft recovered
+Rascunho recuperado
+No draft available to recover
+Não há rascunho para recuperar
+Save Draft
+Salvar Rascunho
+Draft Cleanup
+Limpar Rascunho
+%1 was last modified %2 and was kept
+%1 foi modificado pela última vez em %2 e foi mantido
+%1 was last modified %2 and was deleted
+%1 foi modificado pela última vez em %2 e foi excluído
+Unable to delete draft %s
+Incapaz de excluir o rascunho %s
 Add Comment
 Adicionar Comentário
 ordinary changes
-
+alterações normais
+Matching page names:
+Coincidindo com os nomes de página:
 Footnotes:
 Notas de rodapé: 
 Could not find %1.html template in %2
-
+Não foi possível encontrar o modelo %1.html em %2
 Only Editors are allowed to see this hidden page.
-
+Somente editores podem ver essa página oculta.
 Only Admins are allowed to see this hidden page.
-
+Somente administradores podem ver essa página oculta.
 Index
-
+Índice
 Languages:
-Línguas:
+Idiomas:
 Show!
 Mostrar!
 Define
-
+Definir
 Full Link List
-
+Lista Completa de Links
 Template without parameters
-
+Modelo sem parâmetros
 The template %s is either empty or does not exist.
-
+O modelo %s ou está vazio ou não existe.
  -- defined on %s
-
+ -- definido em %s
 Local names defined on %1: %2
-
+Nomes locais definidos em %1: %2
 Register for %s
-
+Registrar para %s
 Please choose a username of the form "FirstLast" using your real name.
-Escolha um nome de usuário da forma "NomeSobrenome" usando o seu nome verdadeiro.
+Escolha um nome de usuário no formato "NomeSobrenome" usando o seu nome verdadeiro.
 The passwords do not match.
 As senhas não são iguais.
 The password must be at least %s characters.
@@ -662,115 +727,119 @@ Este endereço de email é inválido.
 The username %s has already been registered.
 O nome de usuário %s já foi registrado.
 Your registration for %s has been submitted.
-
+Seu registro para %s foi submetido.
 Please allow time for the webmaster to approve your request.
-
+Por favor, dê tempo para que o webmaster aprove sua requisição.
 An email has been sent to "%s" with further instructions.
-
+Um email foi enviado para "%s" com mais instruções.
 There was an error saving your registration.
-
+Ocorreu um erro enquanto seu registro era salvo.
 An account was created for %s.
-
+Uma conta foi criada para %s.
 Login to %s
-
+Entrada para %s
 Username and/or password are incorrect.
 Nome de usuário e/ou senha inválidos.
 Logged in as %s.
-
+Autenticado como %s.
 Logout of %s
-
+Sair de %s
 Logout of %s?
-
+Sair de %s?
 Logged out of %s
-
+Saiu de %s
 You are now logged out.
-
+Agora você saiu.
 Register a new account
-
-Login
-
+Registrar uma nova conta
 Logout
-
+Sair
 Who am I?
-
+Quem sou eu?
 Forgot your password?
 Esqueceu sua senha?
 Change your password
 Mudar sua senha
 Approve pending registrations
-Aprovar rsgistros pendentes
+Aprovar registros pendentes
 Confirm Registration for %s
-Confirmar resgistro para %s
+Confirmar registro para %s
 %s, your registration has been approved. You can now use your password to login and edit this wiki.
-
+%s, seu registro foi aprovado. Agora você pode usar sua senha para entrar e editar este wiki.
 Confirmation failed.  Please email %s for help.
-
+A confirmação falhou. Por favor, envie um email para %s e solicite ajuda.
 Who Am I?
 Quem sou eu?
 You are logged in as %s.
-
+Você está autenticado como %s.
 You are not logged in.
-
+Você não está autenticado.
 Reset Password
-
+Redefinir Senha
 The password for %s was reset.  It has been emailed to the address on file.
-
+Sua senha para %s foi redefinida. Ela foi enviada para o endereço arquivado.
 There was an error resetting the password for %s.
-
+Ocorreu um erro ao redefinir a senha para %s.
 The username "%s" does not exist.
-
+O nome de usuário "%s" não existe.
 Reset Password for %s
-
+Redefinir Senha para %s
 Reset Password?
-
+Redefinir Senha?
 Change Password for %s
-
+Mudar Senha para %s
 Change Password?
-
+Mudar Senha?
 Your current password is incorrect.
-
+A senha atual não está correta.
 Your password has been changed.
-
+Sua senha foi alterada.
 Approve Pending Registrations for %s
-
+Aprovar Registros Pendentes para %s
 %s has been approved.
 %s foi aprovado.
 There was an error approving %s.
-
+Ocorreu um erro durante a aprovação de %s.
+<ul>
 <ul>
-
 <li>%1 - %2</li>
-
+<li>%1 - %2</li>
+</ul>
 </ul>
-
 There are no pending registrations.
 Não há registros pendentes.
 %s is not a legal name for a namespace
-
+%s não é um nome legal para um espaço de nomes
+ (create locally)
+ (criar localmente)
+image
+imagem
+download
+baixar
 Clearing Cache
-
+Limpando Cache
 Done.
-
+Pronto.
 Generating Link Database
-
+Gerando Banco de Dados de Link
 The 404 handler extension requires the link data extension (links.pl).
-
+A extensão 404 handler requer a extensão link data (links.pl)
 LocalMap
-
+MapaLocal
 No page id for action localmap
-
+Não há id de página para a ação localmap
 Requested page %s does not exist
-
+A página %s requisitada não existe
 Local Map for %s
-
+Mapa local para %s
 view
-
+ver
 Self-ban by %s
-
+Auto-banimento por %s
 You have banned your own IP.
-
+Você baniu seu próprio IP.
 Orphan List
-
+Lista de Órfãs
 Trail: 
 Rastro: 
 None
@@ -778,91 +847,99 @@ Nenhum
 Type
 Tipo
 Permalink to "%s"
-
+Link permanente para "%s"
 There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.
-
+Ocorreu um erro durante a geração do pdf para %s. Por favor, reporte isso ao webmaster, mas não tente baixar novamente, já que não funcionará.
 Someone else is generating a pdf for %s.  Please wait a minute and then try again.
-
+Outra pessoa está gerando um pdf para %s. Por favor, aguarde um minuto e tente novamente.
 Download this page as PDF
-Baixar esta página como PDF
+Baixar essa página como PDF
 Portrait
 Retrato
 Publish %s
-
+Publicar %s
 No target wiki was specified in the config file.
-
+Não foi especificado um wiki alvo no arquivo de configuração.
 The target wiki was misconfigured.
-
+O wiki alvo está mal configurado.
 You did not answer correctly.
-
+Você não respondeu corretamente à pergunta.
+Use the back button to return the previous page and try again.
+Use o botão retornar para voltar à página anterior e tentar novamente.
 To save this page you must answer this question:
-
-All Referrers
-
+Para salvar essa página você deve responder a esta pergunta:
 Referrers
-
+Referenciadores
+All Referrers
+Todos os referenciadores
 Tag
-
+Etiqueta
 Rebuild index for searching
-
+Recriar índice para busca
 Tag Cloud
-
+Nuvem de Etiquetas
 Search::FreeText is not available on this system.
-
+Search::FreeText não está disponível nesse sistema.
 Rebuilding index not done.
-
+Recriação do índice não concluída.
 (Rebuilding the index can only be done once every 12 hours.)
-
+(A recriação do índice só pode ser feita a cada 12 horas.)
+ ... 
  ... 
-
 Search term missing.
 Faltou o termo para a busca.
 Result pages: 
 Páginas de resultado: 
 (%s results)
-
+(%s resultados)
 Tags:
-
+Etiquetas:
 Tags: %s.
-
+Etiquetas: %s.
 No tags
-
+Não há etiquetas.
 Slideshow:%s
-
+Apresentação de slides:%s
+Index of all small pages
+Índice de todas as páginas pequenas
 Static Copy
-
+Cópia Estática
 Back to %s
 Voltar para %s
 Copy to %1 succeeded: %2.
-
+Sucesso na cópia de %1: %2.
 Copy to %1 failed: %2.
-
+Falha na cópia de %1: %2.
 Alternatively, use one of the following templates:
-
+Como alternativa, use um dos seguintes modelos:
 Thread: %s
-
+Linha: %s
 ID parameter is missing.
-
+Parâmetro ID faltando.
 Thread %s does not exist.
-
+Linha %s não existe.
 Page %s does not contain a thread.
-
+A página %s não contém uma linha.
 Add
 Adicionar
 URL parameter is missing.
-
+Parâmetro URL faltando.
 Add to %s thread
-
+Adicionar à linha %s
 Below:
 Abaixo:
 URL:
 URL:
 Name:
 Nome:
-Failed to remove %s
-Falha ao remover %s
+Too many instances.  Only %s allowed.
+Muitas instâncias. Apenas %s permitidas.
+Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.
+Por favor, tente novamente mais tarde. Talvez alguém esteja executando manutenção ou uma longa busca. Infelizmente o site tem recursos limitados e, por isso, pedimos um pouco de paciência.
 Contents
 Conteúdo
+Create a new page for today
+
 This page is a translation of %s. 
 Esta página é uma tradução de %s. 
 The translation is up to date.
@@ -872,33 +949,33 @@ A tradução está desatualizada.
 The page does not exist.
 Esta página não existe.
 http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s
-
+http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s
 http://www.amazon.com/exec/obidos/ISBN=%s
 http://www.amazon.de/exec/obidos/ISBN=%s
 alternate
 alternativa
 http://www.pricescan.com/books/BookDetail.asp?isbn=%s
-
+http://www.pricescan.com/books/BookDetail.asp?isbn=%s
 search
 busca
 Wanted Pages
-
+Páginas Procuradas
 %s pages
-
+%s páginas
 %s, referenced from:
-
+%s, referenciada por:
 Upload of %s file
-
+Envio de arquivos %s
 Blog
 Blog
 Matching pages:
-
+Páginas coincidentes:
 New
 Novo
 Edit %s.
 Editar %s.
 Title: 
-
+Título:
 Tags: 
-
+Etiquetas:
 END_OF_TRANSLATION
