@@ -18,10 +18,14 @@
 #
 # This translation was updated for Oddmuse 1.354.
 #
-$ModulesDescription .= '<p>$Id: bulgarian-utf8.pl,v 1.9 2006/08/18 22:46:10 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: bulgarian-utf8.pl,v 1.10 2007/08/19 11:42:07 as Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Не е разрешено четенето: блокиран потребител, IP адрес или мрежа.
+Login
+
+Error
+
 %s calls
 
 Could not create %s
@@ -40,6 +44,10 @@ Main lock obtained.
 Защита: придобиване на изключителни права.
 Main lock released.
 Премахване на защитата.
+Journal
+
+More...
+
 Comments on this page
 Коментари към тази страница
 XML::RSS is not available on this system.
@@ -58,10 +66,6 @@ No items found in %s.
 
 Click to edit this page
 Кликни тук, за да създадеш тази страница
-image
-
-download
-
 CGI Internal error: %s
 
 Invalid action parameter %s
@@ -84,6 +88,8 @@ Preview only, not yet saved
 Предварителен преглед, още не е записано
 Please go on to %s.
 Моля продължи на %s.
+All changes for %s
+
 No updates since %s
 Няма промени от %s насам
 Updates since %s
@@ -110,6 +116,12 @@ Include minor changes
 %s дни
 List later changes
 Покажи по-ранни промени
+RSS
+
+RSS with pages
+
+RSS with pages and diff
+
 Filters
 Филтри
 Title:
@@ -120,6 +132,8 @@ Username:
 Потребителско име:
 Host:
 Хост:
+Follow up to:
+
 Language:
 Език:
 Go!
@@ -132,6 +146,8 @@ new
 
 from %s
 от %s
+: 
+
 This page is too big to send over RSS.
 
 History of %s
@@ -154,6 +170,8 @@ Missing target for rollback.
 Липсва дата, до която да се върне.
 Target for rollback is too far back.
 Датата за връщане е прекалено стара.
+A username is required for ordinary users.
+
 Rolling back changes
 Връщане на промените
 The two revisions are the same.
@@ -252,6 +270,8 @@ f
 
 Replace:
 Замести:
+Delete
+
 Validate HTML
 Проверка на HTML
 Validate CSS
@@ -346,6 +366,8 @@ Summary:
 Резюме:
 This change is a minor edit.
 Това е малка промяна.
+Cancel
+
 Replace this file with text
 Замени този файл с текст
 Replace this text with a file
@@ -378,6 +400,10 @@ Sample_Undefined_Page
 Пример_на_недефинирана_страница
 Rule "%1" matched "%2" on this page.
 
+Reason: %s.
+
+Reason unknown.
+
 Without normal pages
 
 Include normal pages
@@ -538,6 +564,14 @@ Complete Content
 Пълно съдържание
 The main page is %s.
 Главната страница е %s.
+Archive:
+
+Rebuild BackLink database
+
+Internal Page: 
+
+Pages that link to this page
+
 Cannot highlight the language %s.
 
 Recent Visitors
@@ -598,6 +632,10 @@ November
 
 December
 
+set %s
+
+unset %s
+
 Clustermap
 
 Pages without a Cluster
@@ -610,8 +648,12 @@ Compilation for %s
 
 Compilation tag is missing a regular expression.
 
+List spammed pages
+
 Despamming pages
 
+Spammed pages
+
 Cannot find revision %s.
 
 Revert to revision %1: %2
@@ -620,10 +662,32 @@ Marked as %s.
 
 Cannot find unspammed revision.
 
+Recover Draft
+
+No text to save
+
+Draft saved
+
+Draft recovered
+
+No draft available to recover
+
+Save Draft
+
+Draft Cleanup
+
+%1 was last modified %2 and was kept
+
+%1 was last modified %2 and was deleted
+
+Unable to delete draft %s
+
 Add Comment
 
 ordinary changes
 
+Matching page names:
+
 Footnotes:
 
 Could not find %1.html template in %2
@@ -688,8 +752,6 @@ You are now logged out.
 
 Register a new account
 
-Login
-
 Logout
 
 Who am I?
@@ -748,6 +810,12 @@ There are no pending registrations.
 
 %s is not a legal name for a namespace
 
+ (create locally)
+
+image
+
+download
+
 Clearing Cache
 
 Done.
@@ -796,12 +864,14 @@ The target wiki was misconfigured.
 
 You did not answer correctly.
 
+Use the back button to return the previous page and try again.
+
 To save this page you must answer this question:
 
-All Referrers
-Всички линкове
 Referrers
 Линкове
+All Referrers
+Всички линкове
 Tag
 
 Rebuild index for searching
@@ -830,6 +900,8 @@ No tags
 
 Slideshow:%s
 
+Index of all small pages
+
 Static Copy
 
 Back to %s
@@ -860,10 +932,14 @@ URL:
 
 Name:
 
-Failed to remove %s
+Too many instances.  Only %s allowed.
+
+Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.
 
 Contents
 
+Create a new page for today
+
 This page is a translation of %s. 
 
 The translation is up to date.
