@@ -1,4 +1,4 @@
-# Copyright (C) 2005  Fletcher T. Penney <fletcher@freeshell.org>
+# Copyright (C) 2005-2007  Fletcher T. Penney <fletcher@fletcherpenney.net>
 # Copyright (C) 2005  Alex Schroeder <alex@emacswiki.org>
 #
 # Portions of Markdown code Copyright (C) 2004 John Gruber
@@ -25,14 +25,17 @@
 #	Remainder by Fletcher Penney
 
 #	To enable other features, I suggest you also check out:
-#	MultiMarkdown <http://fletcher.freeshell.org/wiki/MultiMarkdown>
+#	MultiMarkdown <http://fletcherpenney.net/MultiMarkdown>
+
+#	Requires MultiMarkdown 2.0.a2 or higher
 
 
-$ModulesDescription .= '<p>$Id: markdown.pl,v 1.33 2006/04/04 01:16:05 fletcherpenney Exp $</p>';
+$ModulesDescription .= '<p>$Id: markdown.pl,v 1.37 2007/04/02 16:10:19 fletcherpenney Exp $</p>';
 
-use vars qw!%MarkdownRuleOrder @MyMarkdownRules $MarkdownEnabled!;
+use vars qw!%MarkdownRuleOrder @MyMarkdownRules $MarkdownEnabled $SmartyPantsEnabled!;
 
 $MarkdownEnabled = 1;
+$SmartyPantsEnabled = 1;
 
 @MyRules = (\&MarkdownRule);
 
@@ -40,8 +43,6 @@ $RuleOrder{\&MarkdownRule} = -10;
 
 $TempNoWikiWords = 0;
 
-$MultiMarkdownEnabled = 0;
-
 sub MarkdownRule {
 	# Allow journal pages	
 	if (m/\G(\<journal(\s+(\d*))?(\s+"(.*)")?(\s+(reverse))?\>[ \t]*\n?)/cgi) {
@@ -60,38 +61,31 @@ sub MarkdownRule {
     my $source = $_;
     # fake that we're blosxom!
     $blosxom::version = 1;
-    require "$ModuleDir/Markdown/markdown.pl";
-	
-	$MultiMarkdownEnabled = 1 if ($Markdown::VERSION =~ /Multi/);
-
-	if ($MultiMarkdownEnabled) {
-		$Markdown::g_use_metadata = 0;
-		$Markdown::g_use_wiki_links = 0;
-		# $Markdown::g_base_url = $ScriptName;
-	}
+    require "$ModuleDir/Markdown/MultiMarkdown.pl";
 
 	*Markdown::_RunSpanGamut = *NewRunSpanGamut;
 	*Markdown::_DoHeaders = *NewDoHeaders;
 	*Markdown::_EncodeCode = *NewEncodeCode;
+	*Markdown::_DoAutoLinks = *NewDoAutoLinks;
+    *Markdown::_ParseMetaData = *NewParseMetaData;
 
-	# removed for '<' vs '&lt;' issues
-	#*Markdown::_DoAutoLinks = *NewDoAutoLinks; 
-	
-	# UnquoteHtml - undo what Oddmuse does
-	$source = UnquoteHtml($source);
-	
     # Do not allow raw HTML
     $source = SanitizeSource($source);
     
-    # Allow other Modules to process raw text before Markdown
-    # This allows modules to be "Markdown Compatible"
+	# Allow other Modules to process raw text before Markdown
+	# This allows other modules to be "Markdown Compatible"
 	@MyMarkdownRules = sort {$MarkdownRuleOrder{$a} <=> $MarkdownRuleOrder{$b}} @MyMarkdownRules; # default is 0
 	foreach my $sub (@MyMarkdownRules) {
 		$source = &$sub($source);
-	}	
-
+	}
+	
     my $result = Markdown::Markdown($source);
-    
+ 
+	if ($SmartyPantsEnabled) {
+		require "$ModuleDir/Markdown/SmartyPants.pl";
+		$result = SmartyPants::SmartyPants($result,"2",undef);
+	}
+   
 	$result = UnescapeWikiWords($result);
 	
 	$result = AntiSpam($result);
@@ -119,8 +113,7 @@ sub SanitizeSource {
 	# Remember, on a wiki, we don't want to allow arbitrary HTML...
 	# (in other words, this is not a bug)
 
-	# But we do want to allow the use of '<' around links in Markdown
-	$text =~ s/\<(?!(https?|ftp|mailto):)/&lt;/g;
+	$text =~ s/\</&lt;/g;
 	
 	return $text;
 }
@@ -130,13 +123,24 @@ sub SanitizeSource {
 *GetCluster = *MarkdownGetCluster;
 
 sub MarkdownGetCluster {
-  $_ = shift;
-  return '' unless $PageCluster;
-  return $1 if ( /^$LinkPattern\n/)
-    or (/^\[\[$FreeLinkPattern\]\]\n/);
+	$_ = shift;
+	return '' unless $PageCluster;
+	if (( /^$LinkPattern\n/)
+		or (/^\[\[$FreeLinkPattern\]\]\n/)) {
+		return $1
+	};
 }
 
 
+# Let Markdown handle special characters, rather than OddMuse
+*QuoteHtml = *MarkdownQuoteHtml;
+
+sub MarkdownQuoteHtml {
+	my $html = shift;
+
+	return $html;
+}
+
 
 # Change InterMap/NearLink to match >1 space, rather than exactly one
 # So that Markdown can display as codeblock
@@ -180,7 +184,7 @@ sub DoWikiWords {
 	my $text = shift;
 	my $WikiWord = '[A-Z]+[a-z\x80-\xff]+[A-Z][A-Za-z\x80-\xff]*';
 	my $FreeLinkPattern = "([-,.()' _0-9A-Za-z\x80-\xff]+)";
-	
+
 	if ($FreeLinks) {
 		# FreeLinks
 		$text =~ s{
@@ -228,7 +232,7 @@ sub DoWikiWords {
 	# WikiWords
 	if ($WikiLinks) {
 		$text =~ s{
-			([\s])($WikiWord)
+			([\s\>])($WikiWord)
 		}{
 			$1 . CreateWikiLink($2)
 		}xsge;
@@ -252,8 +256,6 @@ sub CreateWikiLink {
 		$id =~ s/__+/_/g;
 		$id =~ s/^_//g;
 		$id =~ s/_$//;
-
-	$title =~ s/_/ /g;
 		
 
 	#AllPagesList();
@@ -267,9 +269,9 @@ sub CreateWikiLink {
 
 	if ($resolved) {
 		if ($class eq 'near') {
-			return "[$title]($resolved)";
+			return "[$title]($ScriptName/$resolved)";
 		}
-		return "[$title](" . UrlEncode($resolved) . ")";
+		return "[$title]($ScriptName/" . UrlEncode($resolved) . ")";
 	} else {
 		if ($title =~ / /) {
 			return "[$title]\[?]($ScriptName/?action=edit;id=$id)";
@@ -299,16 +301,12 @@ sub NewRunSpanGamut {
 	
 	$text = Markdown::_DoCodeSpans($text);
 
-	$text = Markdown::_EscapeSpecialChars($text);
+	$text = Markdown::_EscapeSpecialCharsWithinTagAttributes($text);
 
-	if ($MultiMarkdownEnabled) {
-		$text = Markdown::_DoFootnotes($text);
-	}
-	
 	# Process anchor and image tags. Images must come first,
 	# because ![foo][f] looks like an anchor.
 	$text = Markdown::_DoImages($text);
-	$text = Markdown::_DoAnchors($text);
+	$text = NewDoAnchors($text);
 
 	# Process WikiWords
 	if (!$TempNoWikiWords) {
@@ -316,7 +314,7 @@ sub NewRunSpanGamut {
 
 		# And then reprocess anchors and images
 		$text = Markdown::_DoImages($text);
-		$text = Markdown::_DoAnchors($text);
+		$text = NewDoAnchors($text);
 	}
 	
 	# Make links out of things like `<http://example.com/>`
@@ -329,7 +327,7 @@ sub NewRunSpanGamut {
 	$text = Markdown::_DoItalicsAndBold($text);
 
 	# Do hard breaks:
-	$text =~ s/ {2,}\n/<br \/>\n/g;
+	$text =~ s/ {2,}\n/$Markdown::g_hardbreak/g;
 
 	return $text;
 }
@@ -388,11 +386,10 @@ sub AntiSpam {
 	return $text;
 }
 
-
 sub NewDoAutoLinks {
 	my $text = shift;
 
-	$text =~ s{\<((https?|ftp):[^'">\s]+)>}{<a href="$1">$1</a>}gi;
+	$text =~ s{&lt;((https?|ftp|dict):[^'">\s]+)>}{<a href="$1">$1</a>}gi;
 
 	# Email addresses: <address@domain.foo>
 	$text =~ s{
@@ -453,3 +450,16 @@ sub MarkdownAddComment {
   return $string;
 }
 
+sub NewDoAnchors {
+	my $text = shift;
+	my $WikiWord = '[A-Z]+[a-z\x80-\xff]+[A-Z][A-Za-z\x80-\xff]*';
+		
+	return Markdown::_DoAnchors($text);
+}
+
+sub NewParseMetaData {
+	# Attempting to parse metadata screws up Oddmuse
+	# if there is a colon in the first line (or a link)
+	my $text = shift;
+	return $text;
+}
\ No newline at end of file
