@@ -1,4 +1,4 @@
-# Copyright (C) 2004, 2005, 2006  Alex Schroeder <alex@emacswiki.org>
+# Copyright (C) 2004, 2005, 2006, 2007  Alex Schroeder <alex@emacswiki.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,16 +16,16 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: namespaces.pl,v 1.28 2006/08/24 18:32:53 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: namespaces.pl,v 1.32 2007/06/02 19:19:24 as Exp $</p>';
 
-use vars qw($NamespacesMain $NamespacesSelf $NamespaceCurrent $NamespaceRoot);
+use vars qw($NamespacesMain $NamespacesSelf $NamespaceCurrent $NamespaceRoot $NamespaceSlashing);
 
 $NamespacesMain = 'Main'; # to get back to the main namespace
 $NamespacesSelf = 'Self'; # for your own namespace
 $NamespaceCurrent = '';   # will be automatically set to the current namespace, if any
 $NamespaceRoot = '';      # will be automatically set to the original $ScriptName
 
-my $NamespacesInit = 0;
+$NamespaceSlashing = 0;   # When set, UrlEncode will immediately decode the / added by NamespaceRcLines
 
 # try to do it before any other module starts meddling with the
 # variables (eg. localnames.pl)
@@ -38,8 +38,8 @@ sub NamespacesInitVariables {
     $site{$NamespacesMain} = $ScriptName . '/';
     foreach my $name (glob("$DataDir/*")) {
       if (-d $name
-	  and $name =~ m|/($InterSitePattern)$|
-	  and $name ne $NamespacesMain
+	    and $name =~ m|/($InterSitePattern)$|
+	    and $name ne $NamespacesMain
 	  and $name ne $NamespacesSelf) {
 	$site{$1} = $ScriptName . '/' . $1 . '/';
       }
@@ -70,7 +70,7 @@ sub NamespacesInitVariables {
     $TempDir     = "$DataDir/temp";
     $LockDir     = "$TempDir/lock";
     $NoEditFile  = "$DataDir/noedit";
-    $RcFile	 = "$DataDir/rc.log";
+    $RcFile = "$DataDir/rc.log";
     $RcOldFile   = "$DataDir/oldrc.log";
     $IndexFile   = "$DataDir/pageidx";
     $VisitorFile = "$DataDir/visitors.log";
@@ -95,10 +95,8 @@ sub NamespacesInitVariables {
   }
   $site{$NamespacesSelf} = $ScriptName . '?';
   # reinitialize
+  @IndexList = ();
   ReInit();
-  AllPagesList();
-  NearInit();
-  PermanentAnchorsInit() if $PermanentAnchors;
   # transfer list of sites
   foreach my $key (keys %site) {
     $InterSite{$key} = $site{$key} unless $InterSite{$key};
@@ -163,6 +161,7 @@ sub NewNamespaceDoRc { # Copy of DoRc
   @lines = sort { $a <=> $b } @lines;
   # end, printing
   local *ValidId = *NamespaceValidId;
+  local $NamespaceSlashing = 1;
   if (not @lines and $showHTML) {
     print $q->p($q->strong(Ts('No updates since %s', TimeToText($starttime))));
   } else {
@@ -208,6 +207,15 @@ sub NamespaceRcLines {
   return ($first, @result);
 }
 
+*OldNamespaceUrlEncode = *UrlEncode;
+*UrlEncode = *NewNamespaceUrlEncode;
+
+sub NewNamespaceUrlEncode {
+  my $result = OldNamespaceUrlEncode(@_);
+  $result =~ s/\%2f/\// if $NamespaceSlashing; # just one should be enough
+  return $result;
+}
+
 *OldNamespaceScriptLink = *ScriptLink;
 *ScriptLink = *NewNamespaceScriptLink;
 
@@ -216,10 +224,7 @@ sub NewNamespaceScriptLink {
   local $ScriptName = $ScriptName;
   if ($action =~ /^($UrlProtocols)\%3a/) { # URL-encoded URL
     # do nothing
-  } elsif ($action !~ /=/ and $action =~ /(.*?)%2f(.*)/) {
-    $ScriptName .= "/$1";
-    $action = $2;
-  } elsif ($action =~ /(.*=)(.*?)%2f(.*)/) {
+  } elsif ($action =~ /(.*?)\b($InterSitePattern)\/(.*)/) {
     $ScriptName .= '/' . $2;
     $action = $1 . $3;
   }
