@@ -1,6 +1,7 @@
 # UTF-8 encoded polish translation file for use with Oddmuse
 #
 # Copyright (c) 2006 Radomir Dopieralski
+# Copyright (c) 2007 Marcin Borkowski
 #
 # Permission is granted to copy, distribute and/or modify this
 # document under the terms of the GNU Free Documentation License,
@@ -15,12 +16,16 @@
 # Create a modules subdirectory in your data directory, and put the
 # file in there. It will be loaded automatically.
 #
-$ModulesDescription .= '<p>$Id: polish-utf8.pl,v 1.3 2006/08/18 22:46:10 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: polish-utf8.pl,v 1.5 2007/08/19 11:42:08 as Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Nie wolno Ci czytać tej strony: użytkownik, numer ip lub sieć jest zablokowana.
-%s calls
+Login
+Zaloguj
+Error
 
+%s calls
+%s odwołań
 Could not create %s
 Nie można utworzyć %s
 Invalid UserName %s: not saved.
@@ -30,13 +35,17 @@ NazwaUżytkownika musi mieć nie więcej niż 50 znaków: nie zapisane.
 This page contains an uploaded file:
 Ta strona zawiera wgrany plik:
 Recursive include of %s!
-
+Rekurencyjna inkluzja %s!
 Clear Cache
-
+Wyczyść Cache
 Main lock obtained.
 Uzyskano główną blokadę.
 Main lock released.
 Zwolniono główną blokadę.
+Journal
+Dziennik
+More...
+Więcej...
 Comments on this page
 Komentarze na tej stronie
 XML::RSS is not available on this system.
@@ -48,21 +57,17 @@ historia
 %s returned no data, or LWP::UserAgent is not available.
 %s nie zwrócił danych lub LWP:UserAgent jest niedostępny.
 RSS parsing failed for %s
-Prasowanie RSS nie powiodło się dla %s
+Parsowanie RSS nie powiodło się dla %s
 No items found in %s.
 Nie znaleziono elementów w %s.
  . . . . 
  . . . .
 Click to edit this page
 Kliknij aby edytować tę stronę
-image
-obrazek
-download
-pobieranie
 CGI Internal error: %s
 Wewnętrzny błąd CGI: %s
 Invalid action parameter %s
-Niewłaściwy parametr akcji %s
+Niewłaściwy parametr działania %s
 Invalid URL.
 Niewłaściwy URL.
 Page name is missing
@@ -81,6 +86,8 @@ Preview only, not yet saved
 Tylko podgląd, jeszcze nie zapisane
 Please go on to %s.
 Proszę przejść do %s.
+All changes for %s
+Wszystkie zmiany dla %s
 No updates since %s
 Zadnych zmian od %s
 Updates since %s
@@ -96,9 +103,9 @@ Wyświetl tylko ostatnią zmianę dla każdej strony
 List all changes
 Wyświetl wszystkie zmiany
 Skip rollbacks
-
+Pomiń cofnięcia
 Include rollbacks
-
+Uwzględnij cofnięcia
 List only major changes
 Wyświetl tylko istotne zmiany
 Include minor changes
@@ -107,16 +114,24 @@ Uwzględnij drobne zmiany
 %s dni
 List later changes
 Wyświetl późniejsze zmiany
+RSS
+
+RSS with pages
+
+RSS with pages and diff
+
 Filters
 Filtry
 Title:
 Tytuł:
 Title and Body:
-Tytuł i teskt:
+Tytuł i tekst:
 Username:
 Użytkownik:
 Host:
 Komputer:
+Follow up to:
+
 Language:
 Język:
 Go!
@@ -129,28 +144,32 @@ new
 nowa
 from %s
 z %s
+: 
+: 
 This page is too big to send over RSS.
-Ta strona jest zbyt duża żeby ją wysłać przez RSS.
+Ta strona jest zbyt duża, żeby ją wysłać przez RSS.
 History of %s
 Historia %s
 Compare
 Porównaj
 Deleted
-
+Usunięta
 Mark this page for deletion
-
+Zaznacz tę stronę do usunięcia
 No other revisions available
-
+Nie ma dostępnych innych wersji
 current
-
+aktualna
 Revision %s
 Wersja %s
 Contributors to %s
-
+Współautorzy %s
 Missing target for rollback.
 Nie ma czego cofać
 Target for rollback is too far back.
-Zbyt stare aby cofnąć
+Zbyt stare, aby cofnąć
+A username is required for ordinary users.
+Zwykły użytkownik musi mieć nazwę.
 Rolling back changes
 Cofam zmiany
 The two revisions are the same.
@@ -162,7 +181,7 @@ Cofam do %s
 %s rolled back
 %s cofnięte
 to %s
-
+do %s
 Index of all pages
 Spis wszystkich stron
 Wiki Version
@@ -174,9 +193,9 @@ Hasło
 Run maintenance
 Przeprowadź konserwację
 Unlock site
-Odblokuj strony
+Odblokuj serwis
 Lock site
-Zablokuj strony
+Zablokuj serwis
 Install CSS
 Zainstaluj CSS
 Unlock %s
@@ -186,7 +205,7 @@ Zablokuj %s
 Administration
 Administracja
 Actions:
-Akcje:
+Działania:
 Important pages:
 Ważne strony:
 To mark a page for deletion, put <strong>%s</strong> on the first line.
@@ -196,7 +215,7 @@ Aby zaznaczyć stronę do usunięcia, wpisz <strong>%s</strong> w pierwszej lini
 redirected from %s
 przekierowano z %s
 Click to search for references to this page
-Kliknij aby szukać odniesień do tej strony
+Kliknij, aby szukać odniesień do tej strony
 Cookie: 
 Ciasteczko:
 Warning
@@ -232,7 +251,7 @@ Zobacz aktualną wersję
 View all changes
 Zobacz wszystkie zmiany
 View contributors
-
+Zobacz współautorów
 Homepage URL:
 URL strony domowej:
 s
@@ -249,12 +268,14 @@ f
 f
 Replace:
 Zamień:
+Delete
+
 Validate HTML
 Sprawdź HTML
 Validate CSS
 Sprawdż CSS
 Last edit
-
+Ostatnia edycja
 Difference between revision %1 and %2
 Różnice (pomiędzy wersjami %1 i %2)
 revision %s
@@ -262,9 +283,9 @@ wersja %s
 current revision
 aktualna wersja
 Last major edit (%s)
-
+Ostatnia główna edycja
 later minor edits
-
+Ostatnia pomniejsza edycja
 No diff available.
 Różnice niedostępne.
 Old revision:
@@ -272,7 +293,7 @@ Stara wersja:
 Changed:
 Zmienione:
 Deleted:
-
+Skasowane:
 Added:
 Dodane:
 to
@@ -284,7 +305,7 @@ pokazuję aktualną wersję zamiast niej
 Showing revision %s
 Wyświetlana wersja %s
 Cannot save a nameless page.
-Nie można zapisać bezimiennej strony.
+Nie można zapisać strony bez nazwy.
 Cannot save a page without revision.
 Nie można zapisać strony bez wersji.
 Cannot open %s
@@ -316,7 +337,7 @@ Odblokowanie nie jest konieczne.
 1 second ago
 1 sekundę temu
 just now
-właśnie przed chwilką
+przed chwilką
 Edit Denied
 Edycja Niedozwolona
 Editing not allowed: user, ip, or network is blocked.
@@ -343,10 +364,12 @@ Summary:
 Streszczenie:
 This change is a minor edit.
 Ta zmiana jest drobna.
+Cancel
+Anuluj
 Replace this file with text
 Zastąp ten plik tekstem
 Replace this text with a file
-Zastęp ten tekst plikiem
+Zastąp ten tekst plikiem
 File to upload: 
 Plik do wgrania:
 Files of type %s are not allowed.
@@ -356,7 +379,7 @@ Twoje hasło jest zapisane w ciasteczku, jeśli masz włączoną ich obsługę.
 You are currently an administrator on this site.
 Jesteś obecnie administratorem tej strony.
 You are currently an editor on this site.
-Jesteś obecnie edytorem tej strony.
+Jesteś obecnie redaktorem tej strony.
 You are a normal user on this site.
 Jesteś zwyczajnym użytkownikiem.
 Your password does not match any of the  administrator or editor passwords.
@@ -364,17 +387,21 @@ Twoje hasło nie pasuje do żadnego z haseł edytora ani administratora.
 Password:
 Hasło:
 This site does not use admin or editor passwords.
-Ta strona nie używa haseł edytora ani administratora.
+Ta strona nie używa haseł redaktora ani administratora.
 This operation is restricted to site editors only...
-Ta operacja jest dozwolona tylko dla edytorów strony.,,
+Ta operacja jest dozwolona tylko dla redaktorów strony.,,
 This operation is restricted to administrators only...
-Ta operacje jest dozwolona tylko dla administratorów strony...
+Ta operacja jest dozwolona tylko dla administratorów strony...
 SampleUndefinedPage
-PrzykładNiezdefioniwanejStrony
+PrzykładNiezdefiniowanejStrony
 Sample_Undefined_Page
 Przykład_Niezdefiniowanej_Strony
 Rule "%1" matched "%2" on this page.
 Reguła "%1" pasuje do "%2" na tej stronie.
+Reason: %s.
+Przyczyna: %s.
+Reason unknown.
+Przyczyna nieznana.
 Without normal pages
 Bez zwykłych stron
 Include normal pages
@@ -426,7 +453,7 @@ Nie ma żadnych zmian do zapisania.
 This page was changed by somebody else %s.
 Ta strona została zmieniona przez kogoś innego.
 The changes conflict.  Please check the page again.
-Zmiany konfliktują. Proszę sprawdzić stronę ponownie.
+Wystąpił konflikt zmian. Proszę sprawdzić stronę ponownie.
 Please check whether you overwrote those changes.
 Prosze sprawdzić, czy nadpisałeś te zmiany.
 Anonymous
@@ -438,7 +465,7 @@ Proszę sprawdzić uprawnienia do katalogu.
 Your changes were not saved.
 Twoje zmiany nie zostały zapisane.
 Could not get a lock to merge!
-Nie można uzyskać blokady aby połączyć zmiany.
+Nie można uzyskać blokady, aby połączyć zmiany.
 you
 ty
 ancestor
@@ -466,7 +493,7 @@ Nie można otworzyć pliku logów %s.
 Error was
 Błędem było
 Note: This error is normal if no changes have been made.
-Uwaga: Ten błąd jest normalny jeśli nie było żadnych zmian.
+Uwaga: Ten błąd jest normalny, jeśli nie było żadnych zmian.
 Moving %s log entries.
 Przenoszenie %s wpisów logów.
 Getting page index file for %s.
@@ -484,7 +511,7 @@ Ustawiono blokadę dla %s
 Lock for %s removed.
 Zwolniono blokadę dla %s
 Displaying Wiki Version
-Wyświetlanie Wersji Wiki
+Wyświetlanie wersji Wiki
 Show dependencies
 Pokaż zależności
 Inter links:
@@ -492,11 +519,11 @@ Wewnętrze odnośniki:
 Near links:
 Bliskie odnośniki:
 Show parsed link data
-Pokaż sprasowane dane odnośników
+Pokaż sparsowane dane odnośników
 Too many connections by %s
 Zbyt dużo połączeń z %s
 Please do not fetch more than %1 pages in %2 seconds.
-Proszę nie pobierać więcej, niż %1 stron w ciągu %2 sekund.
+Proszę nie pobierać więcej niż %1 stron w ciągu %2 sekund.
 Check whether the web server can create the directory %s and whether it can create files in it.
 Sprawdź czy serwer WWW może utworzyć katalog %s, oraz czy może tworzyć w nim pliki.
 anchor first defined here: %s
@@ -534,21 +561,29 @@ Dowiedz się więcej...
 Complete Content
 Całkowita zawartość
 The main page is %s.
-Główną stroną %s.
+Główną stroną jest %s.
+Archive:
+
+Rebuild BackLink database
+Przebuduj spis linkujących
+Internal Page: 
+Strona Wewnętrzna: 
+Pages that link to this page
+Strony linkujące do tej strony
 Cannot highlight the language %s.
 Nie można pokolorować źródła dla języka %s.
 Recent Visitors
 Ostatni Odwiedzający
 some action
-jakaś akcja
+jakieś działanie
 was here
 był tutaj
 and read
 i czytał
 Illegal year value: Use 0001-9999
-
+Niedozwolony rok: Użyj 0001-9999
 The match parameter is missing.
-Parametr dopasowania brakuje.
+Brakuje parametru dopasowania.
 Page Collection for %s
 Zbiór stron dla %s
 Previous
@@ -558,9 +593,9 @@ Następny
 Calendar %s
 Kalendarz %s
 Su
-ni
+nd
 Mo
-po
+pn
 Tu
 wt
 We
@@ -568,7 +603,7 @@ We
 Th
 cz
 Fr
-pi
+pt
 Sa
 so
 January
@@ -595,6 +630,10 @@ November
 listopad
 December
 grudzień
+set %s
+ustaw %s
+unset %s
+anuluj ustawienie %s
 Clustermap
 Mapa klastrów
 Pages without a Cluster
@@ -602,13 +641,17 @@ Strony bez klastra
 Comments on 
 Komentarze na
 Comment on 
-Skomentuj na temat 
+Skomentuj 
 Compilation for %s
 Kompilacja dla %s
 Compilation tag is missing a regular expression.
-Brak znacznika kompilacji w wyrażeniu regularnym.
+Brak wyrażenia regularnego w znaczniku kompilacji.
+List spammed pages
+
 Despamming pages
 Odspamowywanie stron
+Spammed pages
+
 Cannot find revision %s.
 Nie można znaleźć wersji %s.
 Revert to revision %1: %2
@@ -617,18 +660,40 @@ Marked as %s.
 Oznaczony jako %s.
 Cannot find unspammed revision.
 Nie można znaleźć czystej wersji.
+Recover Draft
+Odzyskaj brudnopis
+No text to save
+Brak tekstu do zapisania
+Draft saved
+Brudnopis zapisany
+Draft recovered
+Brudnopis odzyskany
+No draft available to recover
+Brak brudnopisu do odzyskania
+Save Draft
+Zapisz brudnopis
+Draft Cleanup
+Czyszczenie brudnopisu
+%1 was last modified %2 and was kept
+%1 było ostatnio modyfikowane %2 i zostało zachowane
+%1 was last modified %2 and was deleted
+%1 było ostatnio modyfikowane %2 i zostało skasowane
+Unable to delete draft %s
+Nie udało się skasować brudnopisu %s
 Add Comment
 Dodaj komentarz
 ordinary changes
 zwykłe zmiany
+Matching page names:
+
 Footnotes:
 Przypisy:
 Could not find %1.html template in %2
 Nie można znaleźć szablonu %1.html w %2
 Only Editors are allowed to see this hidden page.
-
+Tylko redaktorom wolno oglądać tę ukrytą stronę.
 Only Admins are allowed to see this hidden page.
-
+Tylko administratorom wolno oglądać tę ukrytą stronę.
 Index
 Indeks
 Languages:
@@ -642,7 +707,7 @@ Pełna lista odnośników
 Template without parameters
 Szablon bez parametrów
 The template %s is either empty or does not exist.
-Szablon %s jest albo pusty, albo nie istnieje.
+Szablon %s albo jest pusty, albo nie istnieje.
  -- defined on %s
  -- zdefiniowane na %s
 Local names defined on %1: %2
@@ -660,13 +725,13 @@ Adres poczty elektronicznej jest niepoprawny.
 The username %s has already been registered.
 Nazwa użytkownika %s jest już zarejestrowana.
 Your registration for %s has been submitted.
-Twoja rejestracja dla %s zostałą złożona.
+Twoja rejestracja dla %s została wysłana.
 Please allow time for the webmaster to approve your request.
 Proszę dać administratorowi czas na potwierdzenie.
 An email has been sent to "%s" with further instructions.
 Wysłano e-mail do "%s" z dalszymi instrukcjami.
 There was an error saving your registration.
-Wystąpił błąd podczas zpisywania rejestracji.
+Wystąpił błąd podczas zapisywania rejestracji.
 An account was created for %s.
 Konto dla %s zostało utworzone.
 Login to %s
@@ -685,8 +750,6 @@ You are now logged out.
 Jesteś teraz wylogowany.
 Register a new account
 Zarejestruj nowe konto
-Login
-Zaloguj
 Logout
 Wyloguj
 Who am I?
@@ -700,9 +763,9 @@ Potwierdź oczekujące rejestracje
 Confirm Registration for %s
 Potwierdź rejestrację dla %s
 %s, your registration has been approved. You can now use your password to login and edit this wiki.
-%s, twoja rejestracja została potwierdzona. Możesz teraz użyć swojego hasła żeby się zalogować i edytować to wiki.
+%s, twoja rejestracja została potwierdzona. Możesz teraz użyć swojego hasła, żeby się zalogować i edytować to wiki.
 Confirmation failed.  Please email %s for help.
-Potwierdzenie nie powiodło się. Proszę wysłać e-maila do %s aby uzyskać pomoc.
+Potwierdzenie nie powiodło się. Proszę wysłać e-maila do %s, aby uzyskać pomoc.
 Who Am I?
 Kim jestem?
 You are logged in as %s.
@@ -718,7 +781,7 @@ Nastąpił błąd podczas resetowania hasła dla %s.
 The username "%s" does not exist.
 Nazwa użytkonika "%s" nie istnieje.
 Reset Password for %s
-Zrestuj hasło dla %s
+Zresetuj hasło dla %s
 Reset Password?
 Zresetować hasło?
 Change Password for %s
@@ -728,7 +791,7 @@ Zmienić hasło?
 Your current password is incorrect.
 Twoje obecne hasło jest nieprawidłowe.
 Your password has been changed.
-Twoje hasłó zostało zmienione.
+Twoje hasło zostało zmienione.
 Approve Pending Registrations for %s
 Potwierdź oczekujące rejestracje dla %s
 %s has been approved.
@@ -744,7 +807,13 @@ Nastąpił błąd przy potwierdzaniu %s.
 There are no pending registrations.
 Nie ma oczekujących rejestracji.
 %s is not a legal name for a namespace
-
+%s nie jest dozwoloną nazwą przestrzeni nazw
+ (create locally)
+ (utwórz lokalnie)
+image
+obrazek
+download
+pobieranie
 Clearing Cache
 Czyszczenie pamięci podręcznej
 Done.
@@ -756,9 +825,9 @@ Rozszerzenie obsługi 404 wymaga rozszerzenia danych o odnośnikach (links.pl).
 LocalMap
 MapaLokalna
 No page id for action localmap
-Nie ma id strony dla akcji mapy lokalnej
+Nie ma identyfikatora strony dla działania mapy lokalnej
 Requested page %s does not exist
-Rządana strona %s nie istnieje
+Żądana strona %s nie istnieje
 Local Map for %s
 Mapa lokalna dla %s
 view
@@ -786,25 +855,27 @@ Pobierz tę stronę jako PDF
 Portrait
 Portret
 Publish %s
-
+Opublikuj %s
 No target wiki was specified in the config file.
-
+Docelowa wiki nie została określona w pliku konfiguracji.
 The target wiki was misconfigured.
-
+Docelowa wiki jest źle skonfigurowana.
 You did not answer correctly.
 Nie odpowiedziałes poprawnie.
+Use the back button to return the previous page and try again.
+Użyj przycisku powrotu, by wrócić do poprzedniej strony, i spróbuj ponownie.
 To save this page you must answer this question:
-
-All Referrers
-Wszystkie odniesienia
+Aby zapisać tę stronę, musisz odpowiedzieć na pytanie:
 Referrers
 Odniesienia
+All Referrers
+Wszystkie odniesienia
 Tag
 Znaczniki
 Rebuild index for searching
 Przebuduj indeks przeszukiwania
 Tag Cloud
-
+Chmura znaczników
 Search::FreeText is not available on this system.
 Search::FreeText jest niedostępny w tym systemie.
 Rebuilding index not done.
@@ -812,7 +883,7 @@ Przebudowywanie indeksu nie zakończone.
 (Rebuilding the index can only be done once every 12 hours.)
 (Przebudowa indeksu może być dokonana raz na 12 godzin).
  ... 
-
+ ... 
 Search term missing.
 Brak frazy wyszukiwania.
 Result pages: 
@@ -820,13 +891,15 @@ Strony wyniku:
 (%s results)
 (%s wyników)
 Tags:
-
+Znaczniki:
 Tags: %s.
-
+Znaczniki: %s.
 No tags
-
+Brak znaczników
 Slideshow:%s
 Pokaz slajdów: %s
+Index of all small pages
+Spis wszystkich małych stron
 Static Copy
 Kopia Statyczna
 Back to %s
@@ -857,10 +930,14 @@ URL:
 URL:
 Name:
 Nazwa:
-Failed to remove %s
-Nie można usunąć %s
+Too many instances.  Only %s allowed.
+Zbyt wiele instancji - może być tylko %s.
+Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.
+Prosimy spróbować później.  Być może ktoś dokonuje konserwacji serwisu lub jest w trakcie długiego wyszukiwania.  Niestety, nasz serwis ma ograniczone zasoby, więc musimy prosić o odrobinę cierpliwości.
 Contents
 Zawartość
+Create a new page for today
+
 This page is a translation of %s. 
 Ta strona jest tłumaczeniem %s.
 The translation is up to date.
@@ -880,11 +957,11 @@ http://www.pricescan.com/books/BookDetail.asp?isbn=%s
 search
 szukanie
 Wanted Pages
-
+Porządane strony
 %s pages
-
+%s stron
 %s, referenced from:
-
+%s, wspomniana na:
 Upload of %s file
 Wgranie pliku %s
 Blog
@@ -896,7 +973,7 @@ Nowy
 Edit %s.
 Edycja %s.
 Title: 
-
+Tytuł:
 Tags: 
-
+Znaczniki:
 END_OF_TRANSLATION
