@@ -40,7 +40,7 @@ sub process {
 
 package OddMuse;
 
-$ModulesDescription .= '<p>$Id: search-freetext.pl,v 1.50 2006/08/17 14:06:04 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: search-freetext.pl,v 1.53 2007/08/17 12:26:50 as Exp $</p>';
 
 push(@MyRules, \&SearchFreeTextTagsRule);
 
@@ -89,10 +89,10 @@ sub SearchFreeTextIndex {
       return;
     }
   }
-  my $words = SearchFreeTextDB($wordfile);
+  my $words = SearchFreeTextDB($wordfile . ".new");
   $words->open_index();
   $words->clear_index();
-  my $tags = SearchFreeTextDB($tagfile);
+  my $tags = SearchFreeTextDB($tagfile . ".new");
   $tags->open_index();
   $tags->clear_index();
   foreach my $name (AllPagesList()) {
@@ -115,6 +115,8 @@ sub SearchFreeTextIndex {
   }
   $words->close_index();
   $tags->close_index();
+  rename($wordfile . ".new", $wordfile);
+  rename($tagfile . ".new", $tagfile);
   print T('Done.'), "\n";
 }
 
@@ -201,16 +203,16 @@ sub NewSearchFreeTextTitleAndBody {
       push @result, $id if $hash{$id};
     }
   }
+  my $raw = GetParam('raw','');
   # limit to the result page requested
   $max = @result - 1 if @result -1 < $max;
   my $count = ($page - 1) * $limit;
   my @items = @result;
   @items = @items[($page - 1) * $limit  .. $max]
-    unless $CollectingJournal                      # no limit when building a journal,
+    unless $CollectingJournal or $raw              # no limit when building a journal,
       or GetParam('action', 'browse') eq 'rc'      # filtering recent changes or the
       or GetParam('action', 'browse') eq 'rss';    # rss feed.
   # print links, if this is is really a search
-  my $raw = GetParam('raw','');
   my @links = ();
   if (GetParam('search', '') and @items) {
     my $pages = int($#result / $limit) + 1;
