@@ -1,8 +1,8 @@
-# Copyright (C) 2004, 2005, 2006  Alex Schroeder <alex@emacswiki.org>
+# Copyright (C) 2004, 2005, 2006, 2007  Alex Schroeder <alex@emacswiki.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -11,33 +11,45 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the
-#    Free Software Foundation, Inc.
-#    59 Temple Place, Suite 330
-#    Boston, MA 02111-1307 USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-$ModulesDescription .= '<p>$Id: toc.pl,v 1.35 2006/08/06 23:18:14 as Exp $</p>';
+$ModulesDescription .= '<p>XXX $Id: toc.pl,v 1.46 2007/08/17 16:03:09 as Exp $</p>';
 
 push(@MyRules, \&TocRule);
 
 # This must come *before* either headers.pl or the usemod.pl rules and
 # adds support for portrait-support.pl
-$RuleOrder{ \&TocRule } = 90;
+$RuleOrder{\&TocRule} = 90;
 
-use vars qw($TocAutomatic);
+use vars qw($TocAutomatic $TocProcessing $TocShown $TocCounter);
 
 $TocAutomatic = 1;
-my %TocCounter = ();
-my $TocShown = 0;
+my $TocPage;
+
+push(@MyInitVariables, \&TocInit);
+
+sub TocInit {
+  $TocPage = GetId(); # this is the TOC target
+  $TocCounter = 0;
+  $TocProcessing = 0;
+  $TocShown = 0;
+}
+
+# If we're rendering the headings inside the sidebar, we want to refer
+# to the headings in the real page. $OpenPageName points to the
+# $SidebarName, however, so that the forms extension works. That's why
+# we have a separate variable being used, here.
 
 sub TocRule {
-  # Using such a key makes sure that we're not getting confused by
-  # headings in the sidebar.
-  my $key = $OpenPageName||'toc';
-  if (m/\G&lt;toc&gt;/gci) {
+  # When rendering a heading in the SideBar, $TocPage will be ne
+  # $OpenPageBar, making sure that this heading doesn't get an id
+  # attribute. The test for an empty $OpenPageName serves to
+  # facilitate tests.
+  my $id_required = ($TocPage eq $OpenPageName || $OpenPageName eq '');
+  if (m!\G&lt;toc(/[A-Za-z\x80-\xff/]+)?&gt;!gci) {
     my $html = CloseHtmlEnvironments()
       . ($PortraitSupportColorDiv ? '</div>' : '');
-    $html .= TocHeadings() unless $TocShown;
+    $html .= TocHeadings(split(m|/|, $1)) unless $TocShown;
     $html .= AddHtmlEnvironment('p');
     $TocShown = 1;
     $PortraitSupportColorDiv = 0; # after the HTML has been determined.
@@ -53,8 +65,12 @@ sub TocRule {
       . ($PortraitSupportColorDiv ? '</div>' : '');
     $html .= TocHeadings() if not $TocShown and $TocAutomatic;
     $TocShown = 1 if $TocAutomatic;
-    my $TocKey = $key . ++$TocCounter{$key};
-    $html .= AddHtmlEnvironment('h' . $depth, qq{id="$TocKey"});
+    if ($id_required) {
+      $TocCounter++;
+      $html .= AddHtmlEnvironment('h' . $depth, qq{id="toc$TocCounter"});
+    } else {
+      $html .= AddHtmlEnvironment('h' . $depth);
+    }
     $PortraitSupportColorDiv = 0; # after the HTML has been determined.
     $PortraitSupportColor = 0;
     return $html;
@@ -67,9 +83,9 @@ sub TocRule {
 	       || InElement('h6'))
 	   && m/\G[ \t]*=+\n?/cg) {
     return CloseHtmlEnvironments() . AddHtmlEnvironment('p');
-  } elsif ($bol && defined(&UsemodRule)
+  } elsif ($bol && (defined(&UsemodRule) || defined(&CreoleRule))
 	   && !$UseModMarkupInTitles
-	   && m/\G(\s*\n)*(\=+)[ \t]*(.+?)[ \t]*(=+)[ \t]*\n?/cg) {
+	   && m/\G(\s*\n)*(\=+)[ \t]*(.+?)[ \t]*(=*)[ \t]*(\n|$)/cg) {
     my $depth = length($2);
     $depth = 6 if $depth > 6;
     $depth = 2 if $depth < 2;
@@ -78,9 +94,13 @@ sub TocRule {
       . ($PortraitSupportColorDiv ? '</div>' : '');
     $html .= TocHeadings() if not $TocShown and $TocAutomatic;
     $TocShown = 1 if $TocAutomatic;
-    my $TocKey = $key . ++$TocCounter{$key};
-    $html .= qq{<h$depth id="$TocKey">$text</h$depth>}
-      . AddHtmlEnvironment('p');
+    if ($id_required) {
+      $TocCounter++;
+      $html .= qq{<h$depth id="toc$TocCounter">$text</h$depth>};
+    } else {
+      $html .= qq{<h$depth>$text</h$depth>};
+    }
+    $html .= AddHtmlEnvironment('p');
     $PortraitSupportColorDiv = 0; # after the HTML has been determined.
     $PortraitSupportColor = 0;
     return $html;
@@ -92,9 +112,13 @@ sub TocRule {
       . ($PortraitSupportColorDiv ? '</div>' : '');
     $html .= TocHeadings() if not $TocShown and $TocAutomatic;
     $TocShown = 1 if $TocAutomatic;
-    my $TocKey = $key . ++$TocCounter{$key};
-    $html .= qq{<h$depth id="$TocKey">$text</h$depth>}
-      . AddHtmlEnvironment('p');
+    if ($id_required) {
+      $TocCounter++;
+      $html .= qq{<h$depth id="toc$TocCounter">$text</h$depth>};
+    } else {
+      $html .= qq{<h$depth>$text</h$depth>};
+    }
+    $html .= AddHtmlEnvironment('p');
     $PortraitSupportColorDiv = 0; # after the HTML has been determined.
     $PortraitSupportColor = 0;
     return $html;
@@ -103,41 +127,23 @@ sub TocRule {
 }
 
 sub TocHeadings {
-  # Using such a key makes sure that we're not getting confused by
-  # headings in the sidebar. If we're rendering the headings inside
-  # the sidebar, we want to refer to the headings in the real page.
-  # $OpenPageName points to the $SidebarName, however, so that the
-  # forms extension works. That's why we have a separate variable
-  # being used, here.
-  my $key = $SideBarOpenPageName||$OpenPageName||'toc';
-  my $oldpos = pos;          # make this sub not destroy the value of pos
-  my $page = $Page{text};   # work on the page that is currently open!
-  # ignore all the stuff that gets processed anyway
-  $page =~ s!<nowiki>.*?</nowiki>!!gis if defined &UsemodRule;
-  $page =~ s!<code>.*?</code>!!gis if defined &UsemodRule;
-  $page =~ s!(^|\n)<pre>.*?</pre>!!gis if defined &UsemodRule;
-  $page =~ s!##.*?##!!gis if defined &MarkupRule;
-  $page =~ s!%%.*?%%!!gis if defined &MarkupRule;
-  # transform headers markup to usemod markup to 
-  $page =~ s!(.+?)[ \t]*\n===+[ \t]*\n!== $1 =\n!gi if defined &HeadersRule;
-  $page =~ s!(.+?)[ \t]*\n---+[ \t]*\n!=== $1 =\n!gi if defined &HeadersRule;
-  my $Headings           = "<h2>" . T('Contents') . "</h2>";
+  # avoid recursion
+  return '' if $TocProcessing;
+  local $TocProcessing = 1;
+  local $TocCounter; # these numbers must be temporary
+  # don't mess up \G
+  my ($oldpos, $old_) = (pos, $_);
+  my $class = 'toc' . join(' ', @_);
+  my $key = 'toc';
+  # double rendering
+  my $html = PageHtml($TocPage);
+  my $Headings = $q->h2(T('Contents'));
   my $HeadingsLevel      = undef;
   my $HeadingsLevelStart = undef;
-  my $count              = 1;
-  # try to determine what will end up as a header
-  foreach my $line (grep(/^(=|<h\d>)/, split(/\n/, $page))) {
-    my ($depth, $text, $link);
-    if ($line =~ /^(\=+)[ \t]*(.*?)[ \t]*\=+[ \t]*$/) {
-      $depth = length($1);
-      $link = $key . $count;
-      $text  = $2;
-    } elsif ($line =~ /^<h(\d)><a id\="(.+)">[ \t]*(.*?)[ \t]*<\/a><\/h\1>[ \t]*$/) {
-      $depth = $1;
-      $link  = $2;
-      $text  = $3;
-    }
-    next unless $text;
+  my $count = 1;
+  while ($html =~ m!<h([1-6]) id=[^>]*>(.*?)</h[1-6]>!g) {
+    my ($depth, $text) = ($1, $2);
+    my $link = $key . $count;
     $text = QuoteHtml($text);
     if (not defined $HeadingsLevelStart) {
       # $HeadingsLevel is set to $depth - 1 so that we get an opening
@@ -170,8 +176,7 @@ sub TocHeadings {
     $Headings .= '</li></ol>';
     $HeadingsLevel--;
   }
-  pos = $oldpos;
+  ($_, pos) = ($old_, $oldpos); # restore \G (assignment order matters!)
   return '' if $count <= 2;
-  return $q->div({-class=>'toc'}, $Headings)
-    if $Headings;
+  return $q->div({-class=>$class}, $Headings) if $Headings;
 }
