@@ -16,7 +16,7 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: weblog-4.pl,v 1.9 2006/08/06 11:56:40 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: weblog-4.pl,v 1.13 2007/02/20 00:29:37 as Exp $</p>';
 
 push(@MyInitVariables, sub {
        $SearchFreeTextTagUrl = $ScriptName . '?action=browse;tag=1;id=';
@@ -62,10 +62,13 @@ sub DoCategories {
       GetFormStart(undef, 'get', 'cat');
     my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday) = gmtime();
     my $today = sprintf("%d-%02d-%02d", $year + 1900, $mon + 1, $mday);
-    print $q->p(T('Title: '), $q->textfield('id', $today),
+    my $go = T('Go!');
+    print $q->p(T('Title: '),
+		qq{<input type="text" name="id" value="$today" tabindex="1" />},
 		GetHiddenValue('action', 'new'));
-    print $q->p(T('Tags: '), $q->textfield('tags'));
-    print $q->p($q->submit(T('Go!')));
+    print $q->p(T('Tags: '),
+		qq{<input type="text" name="tags" tabindex="2" />});
+    print $q->p(qq{<input type="submit" value="$go" tabindex="3" />});
     print $q->end_form, $q->end_div();
     PrintFooter();
   }
